package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````&",```````!``````````!"B````
M````!0```$``.``*`$``&P`:``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```!P`@``````
M`'`"````````<`(````````A`````````"$``````````0`````````#``!P
M!````*:@`````````````````````````````&8````````````````````!
M``````````$````%````````````````````````````````````$)H`````
M```0F@`````````0`````````0````8```!XFP```````'BK````````>*L`
M``````#8!``````````%`````````!`````````"````!@```)";````````
MD*L```````"0JP```````#`"````````,`(````````(``````````0````$
M````E`(```````"4`@```````)0"````````1`````````!$``````````0`
M````````4.5T9`0```"XD@```````+B2````````N)(```````#L````````
M`.P`````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````>)L```````!X
MJP```````'BK````````B`0```````"(!`````````$`````````+VQI8B]L
M9"UL:6YU>"UR:7-C=C8T+6QP-C1D+G-O+C$`````!````!`````!````1TY5
M```````$````#P`````````$````%`````,```!'3E4`RYPK.88I@%;J(?M1
M'EVHI=;CRB!A````90``````````````40````4```````````````8`````
M```````````````[`````````!`````B````7@`````````O````20```$H`
M```\````60```&(````N````*P``````````````%@```$(````P````````
M``````!+````5````#H`````````50```&0````I````)P````<`````````
M#P`````````Y````6@```$@```!$`````````#8```!<````-0```"T````9
M``````````````!2````10```#@```!!````%````````````````````#X`
M```E````````````````````+````!(`````````"P```&,````;````````
M````````````&````#<````]````3``````````S`````````#\`````````
M`````%L`````````30````````!`````70```$8```!#````)@````T`````
M`````````````````````````````````````````````````````P``````
M````````````````````````````````````````````````````````````
M`&````!.```````````````.````&@````0`````````'@````````!0````
M```````````(`````````!\``````````````%\`````````*@``````````
M````6``````````1`````````&$````H````5@``````````````1P```#$`
M````````(0`````````C````(````!P````,``````````H```!3````````
M`!T`````````````````````````````````````````%0``````````````
M`````!<``````````````#(````D```````````````)````````````````
M``````````````!/````-``````````3`````@````````!7`````````!$`
M``!'````!`````@````@D!`!!4`$Q"@"`02`A@2$@HD``@D@!`B(@!!!N@`"
MB`````!'````2@```$T```!.````5@```%<```!9````6P```%P```!=````
M7P```&$```!B````9```````````````;L7?'\[>1RUK?YI\+L6;MM1DU'PA
M_^0.V7%8'.)'Q@&R`8MOK$OCP$+ZUX?"Y3\LNN.2?/JA;&"93\.;:PE#UF:O
MS&89?@J'0D75[(D'<--S4)_8,V+;[3[/TFP5C"7,##J7"_]A\F%_J9R;X*<"
M"FL:GE"CX/M)```````````````````````````````````````````#``T`
MD"$``````````````````.<"```1`````````````````````````*4"```2
M`````````````````````````'T!```2`````````````````````````(4`
M```2``````````````````````````P"```2````````````````````````
M`(P"```2`````````````````````````,D!```2````````````````````
M`````*X````2`````````````````````````(4"```2````````````````
M`````````*0````2`````````````````````````$@"```2````````````
M`````````````-8!```2`````````````````````````'T````1````````
M`````````````````)4````2`````````````````````````+`!```2````
M`````````````````````-<"```2`````````````````````````/P!```2
M`````````````````````````"$!```2`````````````````````````*$!
M```2`````````````````````````-,````2````````````````````````
M`,,````2`````````````````````````%@````2````````````````````
M``````$````@`````````````````````````!@!```2````````````````
M`````````+T"```2`````````````````````````!T````@````````````
M`````````````(X````2`````````````````````````,H````2````````
M`````````````````*\"```2`````````````````````````),!```2````
M`````````````````````'L````1`````````````````````````-D````6
M`````````````````````````%L!```2`````````````````````````.P`
M```2`````````````````````````(0!```2````````````````````````
M`$4!```2`````````````````````````%L"```2````````````````````
M`````,(!```2``````````````````````````<!```2````````````````
M`````````,@"```2`````````````````````````+4!```2````````````
M`````````````#8!```2`````````````````````````*H"```2````````
M`````````````````&\!```2`````````````````````````-`!```2````
M`````````````````````)<"```2`````````````````````````'8!```2
M`````````````````````````"\!```2`````````````````````````)H!
M```1`````````````````````````"T"```2````````````````````````
M`(L!```2`````````````````````````(T````2````````````````````
M`````$D````B`````````````````````````!@"```2````````````````
M`````````%,!```2`````````````````````````+T!```2````````````
M`````````````.`"```2`````````````````````````'D"```2````````
M`````````````````.<!```2`````````````````````````*H#```2````
M`````````````````````&P"```1`````````````````````````+4````2
M`````````````````````````/P````2`````````````````````````#D"
M```2`````````````````````````#<````2````````````````````````
M`)P````2`````````````````````````&(!```2````````````````````
M`````&H````2`````````````````````````/4!```2````````````````
M`````````+,#```2``T`C$T```````"D`````````$4$```2``T`VD8`````
M```$!0```````$0````2``T`D"$```````"(`0```````"H#```2``T`2#X`
M```````"`````````$@#```2``T`WDL```````"N`0```````&L$```2``T`
M2CX```````"F`0```````"L$```0`!<`4+```````````````````#L#```2
M``T`\#\````````B`````````%X#```2``T`<D0```````!.`````````,L#
M```1``X`0%$````````$``````````@$```2``T`ADX```````#T````````
M`",$```2``T`;#T````````H`````````$`$```0`!<`>+``````````````
M`````%D$```2``T`&$8```````#"`````````(($```2``T`P$0```````!(
M`````````-H#```0`!8``+```````````````````((#```2``T`$D``````
M``#@`````````/8#```0`/'_`+@``````````````````%($```0`!8`4+``
M`````````````````'@$```1`!8`2+`````````(`````````!,$```0`!8`
M4+```````````````````.`#```2``T`&",````````B`````````.<#```0
M`!8``+```````````````````#<$```2``T`,$X```````!6`````````-P#
M```@`!8``+```````````````````+\#```0`!<`>+``````````````````
M`)@#```2``T``D8````````6`````````&P#```2``T`E#T```````"T````
M`````(X#```2``T`>D\```````"T`0```````(H$```2``T`\D````````"`
M`P````````!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE435]R96=I
M<W1E<E1-0VQO;F5486)L90!?7VQI8F-?<W1A<G1?;6%I;@!?7V-X85]F:6YA
M;&EZ90!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]F86EL`%]?96YV
M:7)O;@!S=')N8VUP`&QS=&%T-C0`86-C97-S`&]P96YD:7(`<F5A9&1I<C8T
M`'-T<FQE;@!?7W-P<FEN=&9?8VAK`'5N;&EN:P!C;&]S961I<@!R;61I<@!0
M3%]C=7)R96YT7V-O;G1E>'0`8F]O=%]$>6YA3&]A9&5R`%!E<FQ?;F5W6%,`
M4&5R;%]N97=84U]F;&%G<P!R96%D;&EN:P!097)L7W-V7W-E='!V`&UE;6-H
M<@!097)L7W-V7W-E='!V;@!?7VUE;6UO=F5?8VAK`')E86QL;V,`9V5T<&ED
M`%]?;65M8W!Y7V-H:P!S=')C:'(`<W1R9'5P`'-T<G1O:P!S=')C;7``<W1R
M<F-H<@!M96UC<'D`<W1D97)R`%]?=F9P<FEN=&9?8VAK`&5X:70`;'-E96LV
M-`!R96%D`&UE;6-M<`!G971U:60`;6MD:7(`7U]E<G)N;U]L;V-A=&EO;@!?
M7V9P<FEN=&9?8VAK`&]P96XV-`!097)L7V=V7V9E=&-H<'8`4&5R;%]G971?
M<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]M9U]S970`4&5R;%]S>7-?
M:6YI=#,`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?871F;W)K7VQO8VL`4$Q?
M9&]?=6YD=6UP`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7W!A<G-E`'!E<FQ?
M9&5S=')U8W0`<&5R;%]F<F5E`%!E<FQ?<WES7W1E<FT`<&5R;%]A;&QO8P!P
M97)L7V-O;G-T<G5C=`!P97)L7W)U;@!M96US970`7U]S=&%C:U]C:&M?9W5A
M<F0`;&EB<&5R;"YS;P!L:6)C+G-O+C8`;&0M;&EN=7@M<FES8W8V-"UL<#8T
M9"YS;RXQ`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%A37TEN=&5R
M;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A<E]C=7)R96YT7V5X96-?
M<')O8P!P87)?9&ER;F%M90!S:&%?9FEN86P`9V5T7W5S97)N86UE7V9R;VU?
M9V5T<'=U:60`<&%R7V-L96%N=7``7U]"4U-?14Y$7U\`7TE/7W-T9&EN7W5S
M960`7U]D871A7W-T87)T`%]?1$%405]"14=)3E]?`%]?9VQO8F%L7W!O:6YT
M97(D`'-H85]U<&1A=&4`7U]31$%405]"14=)3E]?`'AS7VEN:70`7U]B<W-?
M<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S
M971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I90!P
M87)?:6YI=%]E;G8`1TQ)0D-?,BXS-`!'3$E"0U\R+C,S`$=,24)#7S(N,C<`
M+W5S<B]L:6(O<&5R;#4O-2XT,"XQ+W)I<V-V-C0M;&EN=7@M=&AR96%D+6UU
M;'1I+T-/4D4```````(``0`#``,``0`!``,``P`#``,``0`#``,``P`#``$`
M`0`!``,``P`#``,``0`#``$``0`$``,``0`#``,``0`#``$``P`#``$``P`!
M``$``P`!``,``P`#``$``P`#``,``0`#``0``P`!``,``P`#``$``P`#``$`
M`P`!``$`!0`#``,``P`#``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``P`$`P``$````$``
M``"TD98&```%`)<$```0````LY&6!@``!`"B!```$````(>1E@8```,`K00`
M```````!``$`#@,``!``````````AY&6!@```@"M!````````'BK````````
M`P`````````Z(P```````("K`````````P````````#,(P```````(BK````
M`````P````````"4(P```````/BO`````````P````````"0(0````````"P
M`````````P``````````L````````!BP`````````P````````"@4@``````
M`""P`````````P````````!XD@```````"BP`````````P````````"`D@``
M`````#"P`````````P````````"(D@```````#BP`````````P````````"0
MD@```````$BP`````````P`````````(50```````*"O`````````@````(`
M`````````````*BO`````````@````P``````````````+"O`````````@``
M``X``````````````+BO`````````@```!@``````````````,"O````````
M`@```!L``````````````,BO````````"P```"$``````````````-"O````
M`````@```",``````````````-BO`````````@```"8``````````````."O
M`````````@```#(``````````````.BO`````````@```#8`````````````
M`/"O`````````@```#X``````````````-"M````````!0````,`````````
M`````-BM````````!0````0``````````````."M````````!0````4`````
M`````````.BM````````!0````8``````````````/"M````````!0````<`
M`````````````/BM````````!0````@```````````````"N````````!0``
M``D```````````````BN````````!0````H``````````````!"N````````
M!0````L``````````````!BN````````!0````T``````````````""N````
M````!0````\``````````````"BN````````!0```!```````````````#"N
M````````!0```!$``````````````#BN````````!0```!(`````````````
M`$"N````````!0```!,``````````````$BN````````!0```!0`````````
M`````%"N````````!0```!4``````````````%BN````````!0```!8`````
M`````````&"N````````!0```!<``````````````&BN````````!0```!D`
M`````````````'"N````````!0```!H``````````````'BN````````!0``
M`!P``````````````("N````````!0```!T``````````````(BN````````
M!0```!X``````````````)"N````````!0```!\``````````````)BN````
M````!0```"(``````````````*"N````````!0```"0``````````````*BN
M````````!0```"4``````````````+"N````````!0```"<`````````````
M`+BN````````!0```"@``````````````,"N````````!0```"D`````````
M`````,BN````````!0```"H``````````````-"N````````!0```"L`````
M`````````-BN````````!0```"P``````````````."N````````!0```"T`
M`````````````.BN````````!0```"X``````````````/"N````````!0``
M`"\``````````````/BN````````!0```#````````````````"O````````
M!0```#$```````````````BO````````!0```#,``````````````!"O````
M````!0```#0``````````````!BO````````!0```#4``````````````""O
M````````!0```#<``````````````"BO````````!0```#@`````````````
M`#"O````````!0```#D``````````````#BO````````!0```#H`````````
M`````$"O````````!0```#L``````````````$BO````````!0```#P`````
M`````````%"O````````!0```#T``````````````%BO````````!0```#\`
M`````````````&"O````````!0```$```````````````&BO````````!0``
M`$$``````````````'"O````````!0```$(``````````````'BO````````
M!0```$,``````````````("O````````!0```$0``````````````(BO````
M````!0```$4``````````````)"O````````!0```$8``````````````)>3
M```S`\-!`[X#_A,#0_V3@@/^$U,3`(.R@@!G``X`%YX```,^#OUG`PX`$P``
M`!>>```#/H[\9P,.`!,````7G@```SX._&<##@`3````%YX```,^COMG`PX`
M$P```!>>```#/@[[9P,.`!,````7G@```SZ.^F<##@`3````%YX```,^#OIG
M`PX`$P```!>>```#/H[Y9P,.`!,````7G@```SX.^6<##@`3````%YX```,^
MCOAG`PX`$P```!>>```#/@[X9P,.`!,````7G@```SZ.]V<##@`3````%YX`
M``,^#O=G`PX`$P```!>>```#/H[V9P,.`!,````7G@```SX.]F<##@`3````
M%YX```,^CO5G`PX`$P```!>>```#/@[U9P,.`!,````7G@```SZ.]&<##@`3
M````%YX```,^#O1G`PX`$P```!>>```#/H[S9P,.`!,````7G@```SX.\V<#
M#@`3````%YX```,^CO)G`PX`$P```!>>```#/@[R9P,.`!,````7G@```SZ.
M\6<##@`3````%YX```,^#O%G`PX`$P```!>>```#/H[P9P,.`!,````7G@``
M`SX.\&<##@`3````%YX```,^CN]G`PX`$P```!>>```#/@[O9P,.`!,````7
MG@```SZ.[F<##@`3````%YX```,^#NYG`PX`$P```!>>```#/H[M9P,.`!,`
M```7G@```SX.[6<##@`3````%YX```,^CNQG`PX`$P```!>>```#/@[L9P,.
M`!,````7G@```SZ.ZV<##@`3````%YX```,^#NMG`PX`$P```!>>```#/H[J
M9P,.`!,````7G@```SX.ZF<##@`3````%YX```,^CNEG`PX`$P```!>>```#
M/@[I9P,.`!,````7G@```SZ.Z&<##@`3````%YX```,^#NAG`PX`$P```!>>
M```#/H[G9P,.`!,````7G@```SX.YV<##@`3````%YX```,^CN9G`PX`$P``
M`!>>```#/@[F9P,.`!,````7G@```SZ.Y6<##@`3````%YX```,^#N5G`PX`
M$P```!>>```#/H[D9P,.`!,````7G@```SX.Y&<##@`3````%YX```,^CN-G
M`PX`$P```!>>```#/@[C9P,.`!,````7G@```SZ.XF<##@`3````%YX```,^
M#N)G`PX`$P```!>>```#/H[A9P,.`!,````7G@```SX.X6<##@`3````'7&&
M[*;DJH>BZ,K@3OR7E```@[0DX"[H,N0,"#``:`@^SIQ@/O2!1^_PG_<7E@``
M`S;&WK*%%Y4```,U)>'O(!!VEY<``(.WY^&#QP<`Z<^7EP``@[>'WA>4```3
M!`3GDI>88W))@T>G2QL%20`.!9/G-P`C#?=*[_"?[<)E%Y8```,VIN/R1P.X
M!0"JAA<W```3!R<N%S4``!,%)2V8[A3D([`&`8CFD.H%1PTI8U;W#*$%&X4W
M`!%'D&&3%S<`MI<%)Y#CH07C&:?^#@<(;#:7(S`'`$J&`4>7)0``DX7%@>_P
M_[P]Q0ALDPE!`N_P/]PJB<Z%%S4``!,%I?KO$`!>*<T(;._PO[;O\'_-(G><
M8+F/`4>]Y^9@1F2F9.)Y2H4&:25A@H#O\)_(%Y0``!,$Q-D(["'%[_"?T9>7
M``"#M\?/A68SAT<`&&,VER,+!Y(YMPAL[_"_O7FW"&@!Q>\@T"E%M\Z%%S4`
M`!,%!>SO$.!6".A9U>6W$4>!OP5%[_`?NN_PW^7O`"`"JH<7E0```S6ES8)E
M,``3<0'_@48!1PJ([_#?X`*0EY$``).!84R"@```%Y4``!,%I="7EP``DX<G
MT&.(IP"7EP``@[?GQ9'#@H>"@!>5```3!87.EY4``).%!<Z)C9/7-4#]D;Z5
MA869Q9>7``"#MZ?#D<."AX*`EY<``(/'Q\N=YT$1!N27EP``@[=GQ)''%Y4`
M``,U1<6"E^_P'_FB8(5'%Y<``",)]\A!`8*`@H!QOQ,!`=27DP``@[/CO#0`
MP6XC/!$J(SB!*B,TD2HC,"$K(SPQ*9,(A0.3#X4'@[<#`",T\2B!1S:(DXX.
M\#</_P`#M@@`H0A!")-5!@(3%X8!$Y.%`9,2A@"35X8"`A<37H8`$U2&`P&3
M`A.S\N(!L_?7`1-3`P(S9U<`,W[>`:(%P8\S9\<!&U:&`;/UY0&SYV<`48_-
MCR,XZ/XC//C^XY'X^T9_YGX*9V)N`G.B>$)XXG6&;Q.$!B`1H+*/L&*<8KJ"
MH0:QC[/'YP&SQ\<!$Y<7`/V#78\"%P&3N/X:CG:/1H.6CL*(+HC^A>,8U/P0
M80QI`SB%`2)N@SB%``,S!0*35[8!$Q=6`#>/@EH3#Y^978]ZGK/&!0$"%QJ>
MD]XH``&3DY?H`;/V%@&SY]<!<I>SQ@8!-I<3G@<"PF837@X"DQ\'`C/'Q0&3
MWP\"<8_ZEI/2OP&3GE\`+8_"EK/N7@`35"8`XF(VEY,6Y@'!CG:7DQX'`K6/
MD]X.`C.'X@&S]_<!$]2^`2Z7DY)>`+/'QP&SXH(`NI<"=!.7[P&3WR\`,V?W
M`9:7@A>3D@8"N8Z!D[,/Y`&3T@("L_;6`7Z>$]2W`9.?5P"SQE8`\I8S[H\`
M\I:B?Q.>[@&3WBX`,V[>`1,4!P*"%C-'QP&!D@&0LX[O`7V/EIZ3GU8`D]*V
M`2&/=I>S[E\`=I?"?Y.>YP&)@[/N_@"S1]X!DQ(.`@(7`9.3T@(",X[O`?6/
M(IZ3'U<`$U2W`;/'5P#RES/NCP#RE^)_$Y[F`8F",V[>`+/&S@$3E`X"@A>!
MDP&0LX[O`?F.EIZ3GU<`D]*W`:&.]I:S[E\`]I:&;Y,>YP$)@[/N[@`S1]X!
MDQ(.`H(6@9*3T@(",X[O`7V/(IZ3GU8`$]2V`3-'5P!RES/NCP!REZ9O$Y[G
M`8F#,V[^`+/'S@$3E`X"`A<!DP&0LX[O`?6/EIZ3'U<`DU*W`:&/]I>S[E\`
M]I?&;Y.>Y@&)@K/NW@"S1MX!DQ(.`H(7@9.3T@(",X[O`?F.(IZ3GU<`$]2W
M`;/&5@#REC/NCP#REN9O$Q[G`0F#,V[N`#/'S@$3E`X"@A:!D@&0LX[O`7V/
MEIZ3GU8`D]*V`2&/=I>S[E\`=I>&?Y.>YP&)@[/N_@"S1]X!DQ(.`@(7`9.3
MT@(",X[O`?6/(IZ3'U<`$U2W`;/'5P#RES/NCP#REZ9_$Y[F`8F",V[>`+/&
MS@$3E`X"@A>!DP&0LX[O`?F.EIZ3GU<`D]*W`:&.]I:S[E\`]I;&?Y,>YP$)
M@[/N[@`S1]X!DQ(.`H(6@9*3T@(",X[O`7V/(IZ3GU8`$]2V`3-'5P!RES/N
MCP!RE^9_$Y[G`8F#,V[^`+/'S@$3E`X"`A<!DP&0LX[O`?6/EIZ3'U<`DU*W
M`:&/]I>S[E\`]I>*;Y.>Y@&)@K/NW@"S1MX!DQ(.`H(7@9.3T@(",X[O`?F.
M(IZ3GU<`$]2W`;/&5@#REC/NCP#REJIO$Q[G`0F#,V[N`#/'S@$3E`X"@A:!
MD@&0LX[O`7V/EIZ3GU8`D]*V`2&/=I>S[E\`=I>3G^<!RFZ)@[/O_P"S1_X!
MDQ(.`@(7`9.3T@(",X[N`?6/(IZ3'E<`$U2W`;/'5P#RES/NC@#RE^ID$]XF
M`).>Y@&"%X&3L^[.`1/9MP&SQM\!$Y0/`A.>5P`!D+./Y`$S;BX!^8Z6GZ&.
M`AX37@X"_I;RE@IY$UXG`).2!@*3'^<!D]("`K/OSP$SQ_X!DY0.`A.>4@"S
M#ND!$]^R`8&0,V[N`7V/HIXECP(>$UX.`G:7$Y3G`8F#<I==C+/'CP"J?A,9
M!P(360D"M8^W]MENDX86NA-?N0$3'ED`,V[N`;:>@A>FGH&3`A[VEQ->#@(^
MGA.?X@&3TB(`,V]?`,IWDQ0.`H&0LT[D`9/2M`&SSNX`@A\3EU0`D]\/`C-G
M5P"VEX(>D]X.`OZ7`A?VEP&3/I>3'ND!$UDI`+/N+@'J=Y,2!P*3T@("LT_?
M`1/9L@&SS\\!`A03GE(``9`S;BX!MI>"'Y/?#P*BEP(>_I<37@X"/IZ3G^0!
MB8"S[Y\`CF<3%`X"`9"SQ/X!$UFT`;F,`A\3%U0`$U\/`C-G)P&VEX(4@9#Z
MEP(7II<!DSZ7$Y_B`9/7(@`S;_\`DQ('`JYGD]("`K/$[P$3V;(!L\3$`8(>
M$YY2`)/>#@(S;BX!MI>"%(&0]I<"'J:7$UX.`CZ>DQ[D`9-7)`"S[OX`$Q0.
M`LYG`9"S1-\!$UFT`;F,@A\3%U0`D]\/`C-G)P&VEX(4@9#^EP(7II<!DSZ7
MDY_B`9/7(@"S[_\`DQ('`NYGD]("`K/$_@$3V;(!L\3$`0(?$YY2`!-?#P(S
M;BX!MI>"%(&0^I<"'J:7$UX.`CZ>$Q_D`9-7)``S;_\`$Q0.`HYW`9"SQ.\!
M$UFT`;F,@AX3%U0`D]X.`C-G)P&VEX(4@9#VEP(7II<!DSZ7DY[B`9/7(@"S
M[OX`DQ('`JYWD]("`K-$WP$3V;(!L\3$`8(?$YY2`)/?#P(S;BX!MI>"%(&0
M_I<"'J:7$UX.`CZ>DQ_D`9-7)`"S[_\`$Q0.`LYW`9"SQ/X!$UFT`;F,`A\3
M%U0`$U\/`C-G)P&VEX(4@9#ZEP(7II<!DSZ7$Y_B`9/7(@`S;_\`DQ('`NYW
MD]("`K/$[P$3V;(!L\3$`8(>$YY2`)/>#@(S;BX!MI>"%(&0]I<"'J:7$UX.
M`CZ>DQ[D`9-7)`"S[OX`$Q0.`I)G`9"S1-\!$UFT`;F,@A\3%U0`D]\/`C-G
M)P&VEX(4@9#^EP(7II<!DSZ7DY_B`9/7(@"S[_\`DQ('`K)GD]("`K/$_@$3
MV;(!L\3$`0(?$YY2`!-?#P(S;BX!MI>"%(&0^I<"'J:7$UX.`CZ>$Q_D`9-7
M)``S;_\`$Q0.`M)G`9"SQ.\!$UFT`;F,@AX3%U0`D]X.`C-G)P&VEX(4@9#V
MEP(7II<!DSZ7DY[B`9/2(@"S[EX`\F>3%`<"@9"S0M\!$]FT`;/"P@&"'Q.>
M5`"3WP\",VXN`;:7@A*3T@("_I<"'I:7$UX.`CZ>DQ+D`9-7)`"SXO(`$Q0.
M`I)W`9"SSUX`$UFT`;//[P`"'Q,75``37P\",V<G`;:7@A^3WP\"^I<"%_Z7
M`9,^EY.?Y`&)@+/OGP"R=Q,9!P(360D",\_R`9-4N0$S3\\!@AX3'ED`D]X.
M`C-NG@"VEP(?$U\/`O:7`A[ZEQ->#@*SCL<!$Q_D`0F`,V^/`-)WDY0.`H&0
M,\[O`1/4M`$S3NX`@A(3EU0`D]("`D&/MI<"'A->#@*6EP(7`9,3%.D!\I<3
M62D`,V0D`3..YP!R=[-'CP"SQ]<!@A^3'@X"D]X.`I/?#P(VEX(7$]F^`8&3
M?I>3GUX`/I>3DN0!L^<O`8F`L^*2`#Z7EF>S3U0`DQ0/`C/.SP$3'P<"$U\/
M`H&0MI<"'I-?OP$37@X"II>3%E\`L^;V`1.7[@'REY/>+@`S9]<!MI>V;K?V
MQB.3'P<"$YX'`I.7)@"3A\?-D]\/`K/FX@`"%!->#@*S]/(!`9"^GK/VY@&B
MGL6.$Q1>`)-4O@'VEK-NE`#VEE9DDQ3O`9->+P"S[M0!$Y\"`C-GUP&3D@8"
MD]("`K,&]``S=\<!,_3^`1-?#P(VGY/4L@%!CQ.44@"3%NX!>I<37BX`,V^4
M`+/FQ@%ZEW9O$Y0&`@&0,^[>``(7`9.S](X`/I\S?EX`?I\S;IX`DQ]7`)-4
MMP%ZGC/OGP!ZGI9T$YGB`1/?(@`S;^D!DQ\.`K/FY@&"'I/?#P*S<H\`,X[T
M`)/>#@+YCG:>L^96`!/9OP&3DE\`DQ3G`9->)P`SA\8!L^;4`3/N(@&V?G*7
MDY(&`I/2`@(S;M\``A<!D[-T7P"^GC-^_@&BGC-NG@`3%%<`DU2W`7:>LVZ4
M`%9TDY3O`9/?+P"S[_0!=IZ3'@X"L^;V`0(?D]X.`C,.]``37P\",_1?`/F.
M>I[!CA/9O@$3E%X`DQ3G`1-?)P`SA\8!L^;D`3-N)`%V?W*7$Y0&`@&0,^[?
M``(7`9.S](\`/I\S?MX!%I\S;IX`DQ)7`)-4MP%ZGC/OD@":8I.4[@&3WBX`
ML^[4`7J>$Q\.`K/FU@&"'Q-?#P(SCO(`D]\/`K/RC@#YCGZ>L^96`!-9OP&3
M$E\`DQ3G`9-?)P`SA\8!L^;T`3/N(@&Z;W*7DY(&`I/2`@(S[MX``A<!D[/T
M7@"^GS-^[@&BGS-NG@`3%%<`DU2W`7Z>LV^4`%IDDQ3O`1-?+P`S[^0!?IZ3
M'PX"L^;F`8(>D]\/`C,.]`"3W@X",W1?`/F.=I[!CA/9OP$3E%\`DQ3G`9->
M)P`SA\8!L^;4`3-N)`'Z;G*7$Y0&`@&0,V[?``(7`9.S=(\`OIXS?OX!EIXS
M;IX`DQ)7`)-4MP%VGK/ND@":<I.4[P&3WR\`L^_T`7:>DQX.`K/F]@$"'Y/>
M#@(SCO(`$U\/`K/RCP#YCGJ>L^96`!/9O@&3DEX`DQ3G`1-?)P`SA\8!L^;D
M`3/N(@$Z?W*7DY(&`I/2`@(S[M\``A<!D[/T7P`^GS-^W@$BGS-NG@`3%%<`
MDU2W`7J>,V^4`%ITDY3N`9/>+@"S[M0!>IX3'PX"L^;6`8(?$U\/`C,.]`"3
MWP\",_1>`/F.?I[!CA-9OP$3%%\`DQ3G`9-?)P`SA\8!L^;T`3-N)`'Z?W*7
M$Y0&`@&0,^[>``(7`9.S](X`OI\S?NX!EI\S;IX`DQ)7`)-4MP%^GK/OD@">
M8I,4[P$37R\`,^_D`7Z>DQ\.`K/FY@&"'I/?#P(SCO(`D]X.`K-RCP#YCG:>
MD]2_`9.>7P"SYE8`DQ+G`0F#,^?B`/*6,^Z>`+YN\I:3$@<"D]("`C-N[P""
M%H&2LW1?`+Z>,W[^`:*>,VZ>`!.45@"3U+8!=IZS;I0`=IY>9).4[P&3WR\`
MDQX.`C/N]`$S9\<!`A^3W@X"LP_T`'6/,W1>`!-?#P)^GT&/DY]>`!/4O@%Z
MES/OCP#^9'J7$Y_F`8F"LV;?``(7`9.3GP8"D]\/`C-OW@`36;<!OI03%%<`
MII(S9"0!LW3^`3-_WP$S;Y\``A0!D!:?GG0BGY,2#P*3T@("$Y3N`9/>+@`S
M9-0!OI23GE(`D]>R`<&.L^[^``(>L_?F`!->#@*3E@X"LW[T`2:>L^?7`?*7
M@9*^EI,4YP$)@]F,$YD&`KY^M[>8,A-9"0(S1Y0`B@>3AV<=,T?G`1,>60`3
M7[D!,V[N`;Z>`A?^G@&3`AX37@X"=I>S#L<!$Y_B`9/2(@`S;U\`DYD.`EY^
MD]D)`C/'Y`&3W[D!-8\"%).660`!D+/F]@$^G@(7(IX!DX(6@9)RES,.UP"3
M'^D!$UDI`+/O+P&3$@X"?G>3T@("LT;_`1/4L@&SSM8!@A23EE(`@9#!CCZ7
M@AZ3W@X")I>"%G:7@9*ZEI.>Z0&3V2D`L^X^`1.4!@(#-P$@`9"SQ-\!$UFT
M`;/$Q`$"'Q,>5``37P\",VXN`3Z7@A2!D'J7`AXFEQ->#@(ZGA.?X@$3UR(`
M,V_O`),2#@(#-X$@D]("`K/$[@$3V;(!M8R"'Y.64@"3WP\"L^8F`3Z7@A2!
MD'Z7@A8FEX&2NI:3'^0!$U<D`+/O[P`3E`8"`S<!(0&0LT3_`1-9M`&SQ,0!
M@AX3'E0`D]X.`C-N+@$^EX(4@9!VEP(>)I<37@X".IZ3GN(!$]<B`+/N[@"3
M$@X"`S>!(9/2`@*SQ-\!$]FR`;6,`A^3EE(`$U\/`K/F)@$^EX(4@9!ZEX(6
M)I>!DKJ6$Q_D`1-7)``S;^\`$Y0&`@,W`2(!D+/$[@$36;0!L\3$`8(?$QY4
M`)/?#P(S;BX!/I>"%(&0?I<"'B:7$UX.`CJ>DY_B`1/7(@"S[^\`DQ(.`@,W
M@2*3T@("LT3_`1/9L@&UC((>DY92`)/>#@*SYB8!/I>"%(&0=I>"%B:7@9*Z
MEI,>Y`$35R0`L^[N`!.4!@(#-P$C`9"SQ-\!$UFT`;/$Q`$"'Q,>5``37P\"
M,VXN`3Z7@A2!D'J7`AXFEQ->#@(ZGA.?X@$3UR(`,V_O`),2#@(#-X$CD]("
M`K/$[@$3V;(!M8R"'Y.64@"3WP\"L^8F`3Z7@A2!D'Z7@A8FEX&2NI:3'^0!
M$U<D`+/O[P`3E`8"`S<!)`&0LT3_`1-9M`&SQ,0!@AX3'E0`D]X.`C-N+@$^
MEX(4@9!VEP(>)I<37@X".IZ3GN(!$]<B`+/N[@"3$@X"`S>!))/2`@*SQ-\!
M$]FR`;6,`A^3EE(`$U\/`K/F)@$^EX(4@9!ZEX(6)I>!DKJ6$Q_D`1-7)``S
M;^\`$Y0&`@,W`24!D+/$[@$36;0!L\3$`8(?$QY4`)/?#P(S;BX!/I>"%(&0
M?I<"'B:7$UX.`CJ>DY_B`1/7(@"S[^\`DQ(.`@,W@263T@("LT3_`1/9L@&U
MC((>DY92`)/>#@*SYB8!/I>"%(&0=I>"%B:7@9*ZEI,>Y`$35R0`L^[N`!.4
M!@(#-P$F`9"SQ-\!$UFT`;/$Q`$"'Q,>5``37P\",VXN`3Z7@A2!D'J7`AXF
MEQ->#@(ZGA.?X@$3UR(`,V_O`),2#@(#-X$FD]("`K/$[@$3V;(!M8R"'Y.6
M4@"3WP\"L^8F`3Z7@A2!D'Z7@A8FEX&2NI:3'^0!$U<D`+/O[P`3E`8"`S<!
M)P&0LT3_`1-9M`&SQ,0!@AX3'E0`D]X.`C-N+@$^EX(4@9!VEP(>)I>3GN(!
M$UX.`I/2(@"S[EX`.IX#-X$GL\+?`;/&T@`"'Q-?#P*3$@X"/I>"%I/2`@*!
MDGJ7DY12`!/9L@$VEQ,?Y`&#-@$H"8`S;X\`L^0D`3/$[@$FE[:7@A\"%S-.
MQ`$!D[*7D]\/`@(>DU:W`1,65P`37@X"_I=5CO*7DY;B`9/2(@"RE[/F5@`S
M!A<!=I,SA[8`0I^"%X&3DQ8&`I,5`P(3%@\"`A>!DH&1`9(!DQSA%.4,\1#M
M@S:!*(.W`P"UCX%&&.F1[X,P@2L#-`$K@S2!*@,Y`2J#.8$I$P$!+(*`[^!_
MD#EQ!OPB^%K@EW<``(.WIW,#NP<`8P$+"$KP3NQ2Z(-'!0"JB2Z**HD3!]`#
MO<-CAN<`@T<9``4)_?L["3E!`S0+`"',)O16Y-J$DPK0`TJ&SH4BA>_@[]6S
M!R0!">6#QP<`8X!7`X!DH01U\*)T`GGB:4)JHFKB<"*%0G0":R%A@H"SA&1!
MC80%"2,@F@!*E/&_`4EMMP%$^;\">>)I0FK9OW%Q(O$F[0;UEW0``(.TA&@L
M`)Q@/N6!1RJ$[^!O]@WAXD>]9A%G]8]CA><`*6=CFN<`(H6)1>_@K]43-14`
M$:`!12IGG&"YCP%'D>>J<`ITZF1-88*`[^"_@#%Q2O$&_1=Y```#.0EC@S<)
M`#[E@4<9Q2+Y@T<%`"J$B>]*="IG@S<)`+F/`4=CG@<,ZG`*>2EA@H`F]>_@
MK_JJA&,*!0Q.[2:%[^#/S$G-@T8U`9,)-0&;AB;]&X8&`)GB`\89`&W2`T<U
M`1L')_V;!@<``>N#QQD`FX<G_9N&!P"MS_'2(H52Z>_@S\8JBDZ%[^!/QCL*
MJ@`)*E*%[^"/QLZ'4H8BAY<6``"3AF9SB46JB>_@+^\L`$Z%[^"OTOU78PCU
M`.)'O6819_6/8XKG`DZ%[^`OS4Z%[^#/W":%2FKOX$_#+?4FA>_@S]`BA>_@
M;\I*=*ITZFDMMX/&*0!1MTZ%[_#?[\&_(ODF]4[M4NGOX$_O2G2J="FW01$B
MX!=T```#-.13!N279@``DX;&@+,'1`"(8Q=V```#-N92EQ4``).%96KOX._F
M$I0(8`)DHF`7)P``$P<GH[J&@4<7%@``$P9&$9<5``"3A>5I00%OX$_/77&B
MX/UR!60F_$KX3O12\(;D5NP3!X0`%I$*EY=Y``"#N4E**HDNBA,&]/\L`!<5
M```3!:5G@[<)`!SC@4?OX"_!FP0%`&->D`"3!P0!BI<SA(=`FX?T_SZ4`T>$
M_RGCG>^7=P``@[=G2%*&RH62EXAC[^#ON(5GH0>*EYAC@[<)`+F/`4>IXX5B
M%I&F8`9DXG1">:)Y`GKB:F%A@H"^A"``(H4FAI,%\`+OX&_-5=F7=P``@[>'
M0Z:&(H:2EXACRH7OX._%1;_OX(_<67&B\*;LRNB&],[DTN!:^%[T%WD```,Y
M*3X#QP4`@S<)`#[D@4>3!]`#+H2JA&,4]P`3A!4`(H7OX,^G*HI,`":%[_`?
MR*J):<GOX*^F8W5%"Q)+EWL``(.["SL."P/'!`"FAY,&T`-C#@<28P;7``/'
M%P"%!WW[A9^#N0L`$P4J`#Z5VIGOX.^C(["I`"G%@[<+``/'!``3A10`VI>4
M8Q,&T`,C@.8``>NUH`-'!0`%!:.`YP`EP[:'A0;C&,?^$P?0`R.`YP"%!P-'
M!``%!(4'HX_G_G7[(F>#-PD`N8\!1_'GIG`&=.9D1FFF:09J0GNB>V5A@H"#
M1P0`!02%":./^?[QVX-'!``%!(4)HX_Y_OWST;>VAV6W5OQB\&;LEWL``(.[
M2RZ#O`L`@[<,`*7/YH>!29AGH0?.AH4I9?^-)I.:-@"7=P``@Z=G-A=W```3
M!^<UA>^%1U:%',/OX&^6*HPQR1.;.0#6AN:%6H;OX$^I(["+`9N'&0".!SZ<
M(S`,`.)Z`GSB;$["R;W6A6:%[^`OMR.PJP`JC!'-$YLY`-F_@4?1O<%*@4EI
MOU;\8O!F[._@#\'B>@)\XFPIOY=W``"#M\<EEU8``).&QE(7=@```S9&)9*7
MB&.7%0``DX6%/&_@#[E=<?ERB6>&Y*+@)OQ*^$[T4O`3AX<!%I$*EY=Y``"#
MN2D?@[<)`!SC@4?OX"^=A6?!!S,$\0`%9BJ'!08BA9<7``"3AV<\EQ8``).&
M9CR)1>_@S[(D`"*%IH4%9N_@#Y0;!`4``4EC000"&PH4`%*%[^#/ABJ)"<DB
MAM*&IH5*E._@S[0C``0`B6?A!XJ7F&.#MPD`N8\!1X'OB6(6D:9@2H4&9.)T
M0GFB>0)Z86&"@._@S[*QMQ5Q_7*%9Z+IIN7*X5KQANU._5+Y5O5>[6+I$X>'
M"!:1"I<7>P```SM+$RJ)+H07%0``$P4%-$P`@S<+`!SC@4?O\%^>JH23!?`"
M2H7OX*^8,<$7%0``$P7%,LJ%[_!_T$J%A6>3AX<(BI>88X,W"P"YCP%'8Y<'
M$H5B%I'N8$YDKF0.:>IY2GJJ>@I[ZFM*;"UA@H`BA>_@#Y>7%0``DX5%+^_0
M7_(JA$W5A6J3APH)BI>SBU=!@T<$`),)@0@3"H$`V<^1Q**%)H7OX,^()<TB
MA>_07_23!_7_HI<JC),&\`)C:/0`,:@C@`<`_1=C!O0``\<'`.,)U_XBA>_0
MO_$JC$J%[]`_\6*5!07C<U7UB44BATJ(EQ<``).'!RB7%@``DX8&*`5F3H7O
MX,^9TH5.A>_07_T!Z8.GB_B]9B%G]8]C@.<$EQ4``).%A20!1>_0?^<JA.,.
M!>Z#1P0`O?.9R(/'!`";AR?]&X<'`)GC`\<4`&G;!4P7%```$P3D'DFWA45.
MA>_0'^U5_<Z%%Q4``!,%!1_O\-^\3H7OX*^&R;7OX$^801&3!?`"(N`&Y"J$
M[^!/B!G!$P05`"*%`F2B8$$!;^`OA'EQA6?]<DKH!O0B\";L$X>'`!:1%WD`
M``,YJ?<*EX,W"0`<XX%'0<&#1P4`JH2ES^_0_^$3!A4`A6<JA&/NQP@X`*:%
M.H7OT)_RDP?T_ZJ7DP;P`F-H]0`1J".`!P#]%V.&IP`#QP<`XPG7_B``(H63
M!?`"[]"__QW%8VRD!"@`[]#_^X5GH0>*EYAC@S<)`+F/`4>AYX5B%I&B<`)T
MXF1":45A@H"%9Z$'BI>88X,W"0"YCP%'G>.%8A:1HG`"=.)D0FD7%0``$P6E
M#45A;]`?]R,`!0!EMP%%;;?OX"^(>7$B\";L2N@&])=T``"#M$3JG&`^Y(%'
M0``7>0```SE)ZJ*%%Q4``!,%I0WO\`_U#<421X,W"0`.![J7F&>8XVW3F&NA
M!YCC;?^BA1<5```3!24+[_"/\FG]%WD```,Y2>:BA1<5```3!:4*[_`/\0W%
M$D>#-PD`#@>ZEYAGF.-MTYAKH0>8XVW_HH47%0``$P4E"._PC^YI_1=Y```#
M.4GBHH47%0``$P4E!^_P#^T-Q1)'@S<)``X'NI>89YCC;=.8:Z$'F.-M_Z*%
M%Q4``!,%I03O\(_J:?T7>0```SE)WJ*%%Q4``!,%)03O\`_I#<421X,W"0`.
M![J7F&>8XVW3F&NA!YCC;?^BA1<5```3!:4![_"/YFG]%WD```,Y2=JBA1<5
M```3!:4`[_`/Y0W%$D>#-PD`#@>ZEYAGF.-MTYAKH0>8XVW_HH47%0``$P4E
M_N_PC^)I_1=Y```#.4G6HH47%0``$P6E_>_P#^$-Q1)'@S<)``X'NI>89YCC
M;=.8:Z$'F.-M_Z*%%Q4``!,%)?OO\(_>:?T7>0```SE)TJ*%%Q4``!,%)?+O
M\`_=#<421X,W"0`.![J7F&>8XVW3F&NA!YCC;?^BA1<5```3!:7O[_"/VFG]
M%WD```,Y2<ZBA1<5```3!:7V[_`/V0W%$D>#-PD`#@>ZEYAGF.-MTYAKH0>8
MXVW_HH47%0``$P4E]._PC]9I_1=Y```#.4G*HH47%0``$P6E\^_P#]4-Q1)'
M@S<)``X'NI>89YCC;=.8:Z$'F.-M_Z*%%Q4``!,%)?'O\(_2:?T7>0```SE)
MQJ*%%Q4``!,%I?#O\`_1#<421X,W"0`.![J7F&>8XVW3F&NA!YCC;?^BA1<5
M```3!27N[_"/SFG]%WD```,Y2<*BA1<5```3!27C[_`/S0W%$D>#-PD`#@>Z
MEYAGF.-MTYAKH0>8XVW_HH47%0``$P6EX._PC\II_:*%%Q4``!,%)>KO\(_)
MJH49Q1<5```3!27G[_!O_**%%Q4``!,%Q>GO\*_'JH49Q1<5```3!47J[_"/
M^J*%%Q4``!,%9>KO\,_%JH4=R1<5```3!>79[_"O^")GG&"YCP%'H>,"=*)P
MXF1":9<5``"3A07J%Q4``!,%!=Y%86_P+_:BA1<5```3!07G[_!OP:J%8=47
M%0``$P4%WN_P3_1MO^_0/]`!$2+H!NP7=````S2$LDP`%Q4``!,%Y=L<8#[D
M@4?O\.^]%<&#1P4``46)QY.'!_TS-?``(F<<8+F/`4>9Y^)@0F0%88*``47U
MM^_07\L=<0;L%W,```,SP[$JC@,U`P`3`X$"+O0R^#;\<H:ZX!=^```#/@ZL
MON3"Z,;LFH:)18,W#@`^Y(%'&N#OT%^?$P7P#^_0WYI=<<%RP6=*^$[T4O"&
MY*+@)OQ6[%KH$X>'`!:1"I<7>@```SJJIX,W"@`<XX%'"4:!1:J)[]!?JQ,)
M]?\35_E#09.S!^D`PA?!DYF/,PGY0&-%"0B*A/U:'4L!1LJ%3H7OT)^H8P-5
M"4%F(0:FA4Z%[]"?M`$E8P15!V-\JP1A%3.$I`!C=I0`J:!]%&-CE`0A1I=U
M``"3A>6F(H7OT-^A;?4S!21`2I7!9Z$'BI>88X,W"@"YCP%'G>_!8A:1IF`&
M9.)T0GFB>0)ZXFI":V%A@H#!=SZ9XQ+Y^'U5\;<7%0``$P6ET._P/^T7%0``
M$P7ESN_P?^SOT#^W01$&Y._0OX3OT'^O$<$(8:)@00&"@#EQ)O1*\`;\%WD`
M``,Y"9BJA$P`%Q4``!,%1<V#-PD`/N2!1^_P+Z,9Q2+X@T<%`"J$G>-"=")G
M@S<)`+F/`4>FA1<5```3!67*M>?B<*)T`GDA86_P#]0FA4[L[]#/_JJ)(H7O
MT$_^JIF)"4Z%[]"O_B*()H>7%P``DX>GM$Z&EQ8``).&!K6)12J$[]#?IB)G
M@S<)`+F/`4>5XZ*%0G3B:>)PHG0">1<5```3!07$(6%O\"_.(OA.[._0_ZGO
MT+^IEW<``).'YY(#N(<#27$#OP<!@[Z'`0.^!P(#LX<"@[@'`Z;NRNK.YH;V
MHO)D")=Y``"#N8F)*HD7%@``$P9FP)<6``"3AF:I%Q<``!,'Y[^7%P``DX?G
MOT+AIH47%0``$P4EJ`.X"0!"Y@%(@N@"_/KL]O#R])KXQORRX+;D.O0^^._P
M+Y$1Q8-'!0`JA&.7!R+2XE;^6OI>]N_0S^WOT)^88P@%&(,Z!0!CA`H85H7O
MT&_M$Q05``4$(H7OT*_M`\<*`"J+HHLJB@7/EQ8``).&)KDBAHE%6H7OT-^5
MA0K>AF/SBP"BAK.'AD")!V/SUP"VAP/'"@!Y%!6,/I0)"W'WDPJ!!1<5```3
M!06L*:`#M8H`H0H-P::%[_"OARJ$9=F#1P4`[=?O\.^0==$BA>_0?X0JA!7A
MDPH!!`.T"@`)S(-'!`!CA`<.(H7O\*^.>>4#M(H`H0IM]"*%[]"OXJJ*4H7O
MT"_BNXJJ`)N*2D!6A>_03^*7%P``DX<'F=*((H=6AA<8```3""BNEQ8``).&
M)JZ)12J+[]#_B5J%DP4`'._03_O]5V,8]0#OT*_@'$%%1V.4YPYF[I,,@0CF
MA5J%[]!/_RJ$&>7J1[UF$6?UCV.&YPJ79P``@[<'<X,V"0"(8UJ'%Q8``!,&
MAJV)1>_0?X+R;`%*,F>#MPD`N8\!1V.5!RZV<!9T\GI2>[)[]F16:;9I4H46
M:G5A@H`BA>_0;_4JA*$*XPH%\#VW`40MMR`0"&`9R::%[^"_]0'%@T<%`)7C
M"&0A!'WU-47OT(_4M4LJBRJ*7H27&@``DXK*G1,',`6=M>_0[_"JBB$$<='O
MT$_1$Q05``4$/;T*6N_0;\_C&:KTZD=B\A,'`!R3]_<?8X;G!!)\-;\79P``
M`S>G9H,V"0`(8Q<6```3!D:=6H>)1>_0#_8UO^_P/\@R9X.W"0"YCP%'8Y4'
M(B*%%G2V</9D5FFV:75A;]"OZ5:%[]!/RZ:%*HH7%0``$P7%HN_@/^JJA6,,
M!1`#-0D`[_`/QRJ,8P4%$&*%[]"OQYL+!0"-1V/8=P,3A<O_8I67%0``DX7E
MG^_0[]D)[9%'8X+[&)N'N__BEP/'!P"3!_`"8PGW%J:%%Q4``!,%Y8'OX%_D
M:<&#1P4`U<\3!P`#8XOG"I<5``"3A:6)%P4``!,%I7_O\.^5[]#OTRJ(6H=6
MAE*%EQ@``).(**F7!P``DX>G=Y<6``"3AJ:;B47OT(_I_51%29<;``"3BPNG
M%:COT&_`'$%CG2<#[]#/SP4D*HA>X**(6H=6AE*%EP<``).'IW.7%@``DX:F
MF(E%[]"/Y9,%`!Q2A>_0[];C`I7\6H7OT$_4TH47!0``$P5E;N_P+XU2A>_P
MG[,2?/)L[;,#/`D`W;UBA8%%[]#/Z*J$,='O\-^@*HGC3@7RDP5E_P%&)H7O
MT"_.DPL!`MZ%)H491N_03]J91V,<]0@"5[='04.3AP<PXQ?W\`/72P"19Y.'
MAU3C$/?PDP7I_`%&)H7OT&_*)H7FA1,&@`+OT*_6DP>``F,>]01FB%:&EQ@`
M`).(J)B7!P``DX<G9UJ'EQ8``).&!HJ)15*%(P@!"N_0C]@]OP,YB0#C!PGH
M2H7OT(^LC4?C\:?H<15*E9<5``"3A:6%[]`OO^,7!>9*C*6U%Q4``!,%Y83O
M\/^/8O)F[N_0;]K2XE;^6OI>]F+R9N[OT&_9.7$B^!=D```#-&0^2O!.[`;\
M)O12Z+,'1`"$8Y,)00`7:0```SDI.H/'!`O.A1<%```3!45A`S<)`#KD`4>C
MB/0*[^#_Q!G%`T<%`),'$`-C"_<2[_`/S+,'1`"$8R:%C48%1I<5``"3A>6`
M[]!OJ*J$'<$<:3,'1``(8XQC%P8``!,&QG_OT,^GG&B,8]Q%$Y>7`F-%!Q"S
M!T0`B&.-1@5&EP4``).%!7[OT(^DJH07:@``$PJJ/`W!SH47!0``$P7E4N_@
MW[R<:"J&C&-IP;,'1`"(8^_0SZ*S!T0`A&,%1I<%``"3A85Z)H7OT&^6JH47
M!@``$P8&>R:%[]!OH!*4'&#.A1<%```3!45-HX@'"N_@_[<C.*H`*H0YQ9,%
M`!PBA>_0[[(;!Q4`A4=C\.<"Q4=C#?4`@S>*`*J&(H:,8Q<%```3!05Y[]"/
MMR)G@S<)`+F/`4>IZ^)P0G2B=`)YXFE":B%A@H`#-8H`[_#_F",XJ@`JA%WQ
M%P4``!,%!7/OT`^T@T<5`..*!^S9M8,WB@`NA8QC[^"_UCV_LP=$`(AC[]#O
MKL6][]"/OGEQ(O`F[`;T%V0```,TQ""JA$P`%P4``!,%!4H<8#[D@4?OX!^L
M`<V#1P4`B<L3!P`#8X;G`('$@\<$`)GK(F<<8+F/`4>A[Z)P`G3B9$5A@H`F
MA4KH[_`/HY,%\`(JB>_03ZD9P1,)%0!*A>_0CZ411I<%``"3A254[]"O@1G!
M0FEUOR)G'&"YCP%'D>L"=$)IHG`FA>)D16%OX%^T2NCOT$^T01$3!0`(!N3O
MT(^#%T@```,XR$6W=EU,-W?I888&MR5%9S=6,A`&!Y.&YL^3A14P$P9F1Q,'
M!Q\4Z2,T!0(C.`4"(RP%!@SA(S0%`1#M&/&B8$$!@H!=<2;\2OA2\%;LAN2B
MX$[T&'63%S8`,HFZEQ!Y@A>!DS.WYP"JA)-6V0$H73J6,X?&`)STF/BNBA.*
MA`,M[9,'\`-CVB<%FUEI`%KH&XOY_U[DF@F3&PL"D]L+`M:95H2BA1,&``12
MA>_0+XD3!`0$)H7OT&_-XQ4T_SL+8$$;&VL`F@L;"0G\DXH*!#L)*P'>FD)K
MHFO6A5*%2H;OT.^%(ZPD!Z9@!F3B=$)YHGD">N)J86&"@),'``2)GSZ$8TGY
M`IL)!``3BH0#3H92E=:%[]"O@KQ<$P<`!*&?O-SCD^?\)H4["8E`SIKOT._%
M@;]*A,&_.7$B^";T3NQ2Z%K@!OQ*\%;D`[F%`H/6A0(#UP4#DU<Y`!.+A0.3
M]_<#D]F&`!-:AP";EH8`&Q>'`#,&^P`NA+/IV0"3!0#X,VKJ`(,Z!`.%)R,`
MM@#"&4(:$P:``ZJ$D]D)`S,%^P`36@H#8U7V$!,'``2[!_=`$4=C_^<0"4=C
M\^<08YX'#B*%[]"OO%J%$P:``X%%[]`/C)-7B0$3UXH!$UD)`9/:"@$C&40'
M(QLT!Z,(5`<C"O0&HPHD!R*%(PCD!N_0#[D<8"*%X8,C@/0`'&#!@Z.`]``<
M8*&#(X'T`!Q@HX'T`!QDX8,C@O0`'&3!@Z."]``<9*&#(X/T`!QDHX/T`!QH
MX8,CA/0`'&C!@Z.$]``<:*&#(X7T`!QHHX7T`!QLX8,CAO0`'&S!@Z.&]``<
M;*&#(X?T`!QLHX?T`!QPX8,CB/0`''#!@Z.(]``<<*&#(XGT`!QPHXGT`$)T
MXG"B=`)YXFE":J)J`FLA86_`7_(=GH%%[\#?_3&_(P`%`!&W(P`%`*,`!0#Y
M%SJ5XXL'[NVW(P`%`*,`!0`C`04`HP$%`/$7.I4)1^/KY^S1OY=F``"#MB;M
M;\"_W@````````$``@``````)7,O)7,```!$>6YA3&]A9&5R.CIB;V]T7T1Y
M;F%,;V%D97(``````$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"]P<F]C+W-E
M;&8O97AE``!E>&4``````"]P<F]C+R5I+R5S```````N`````````%!!4E]4
M14U0``````````!005)?4%)/1TY!344`````.@`````````O`````````"5S
M)7,E<P``4$523#5,24(``````````%!%4DQ,24(`4$523#5/4%0`````````
M`%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$``````!005)?
M0TQ%04X`````````4$%27T1%0E5'`````````%!!4E]#04-(10````````!0
M05)?1TQ/0D%,7T1%0E5'``````````!005)?1TQ/0D%,7U1-4$1)4@``````
M``!005)?5$U01$E2````````4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?
M0TQ%04X``````````#$`````````;'-E96L@9F%I;&5D`````')E860@9F%I
M;&5D``````!,1%],24)205)97U!!5$@`4UE35$5-```O=&UP`````%5315(`
M````55-%4DY!344``````````"4P,G@`````<&%R+0`````E<R5S)7,E<P``
M````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`H97)R;F\])6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C
M=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y
M('EO=7(@;W!E<F%T:6]N*0H```````!0051(`````'!A<FP`````+G!A<@``
M``!S:&]R="!R96%D````````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U
M)7,````E<R5S=&5M<"TE=2TE=25S```````````8`````````'!E<FP`````
M,`````````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`V,P```%5N86)L
M92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE
M<G)N;STE:2D*```````````M90```````"TM````````979A;"`G97AE8R`O
M=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U
M;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H
M)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I
M>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%
M7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S
M:7IE(#T@-#`["B102UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@
M9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ
M92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY
M("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@
M("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ
M90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D
M("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD[
M"FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I
M('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]
M"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F
M:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]
M*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S
M96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F
M:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H
M<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*
M<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G
M35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%4
M12`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI
M.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\
M/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@
M)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R
M96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL
M96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64[
M"FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES
M=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S
M('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.
M('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA
M;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<
M)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO
M=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*
M;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)
M0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO
M<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@
M<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A
M(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM
M>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G
M:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG
M("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'
M24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I
M8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?
M<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@
M;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D
M8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H92!M87)K97(@9F]U
M;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U
M9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S
M971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE
M.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E
M="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L
M("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L(#`[
M"B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I
M<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@
M97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U
M=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R
M8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@
M.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_
M.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?
M1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT
M*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I
M;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE
M.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^
M("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E
M<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0[
M"GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@
M0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN
M9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN
M9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U
M;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#
M3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]
M($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T
M96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN
M9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L
M<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M
M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*
M;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B
M0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U
M;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q
M=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME
M>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M
M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@
M/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*
M9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI
M>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65]
M.PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II
M<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE
M(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M
M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A
M<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D[
M"F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A21553
M12!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@
M;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*
M;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L
M;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I
M9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G
M*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@
M0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A
M9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!
M24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@
M>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2![
M"F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T
M($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@
M)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]
M"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF
M("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG
M*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E
M;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD
M8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@
M/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII
M;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?
M*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?
M:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D
M<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG
M="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ
M1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@
M(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M
M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A
M(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE
M=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D
M("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q
M6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E
M860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F
M:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*
M?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*
M)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H
M*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A
M;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*
M<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1S=&%R
M=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R
M=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD968[
M"B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P
M;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@
M*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE
M<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U
M;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C
M:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP
M?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY
M("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA
M<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF
M:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S
M(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H
M;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F
M:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M
M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD
M?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF
M("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D
M<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D
M<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L
M("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT
M('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE
M?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L
M:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S
M(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM
M>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL
M92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@
M)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I
M;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^
M+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@
M+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M
M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*
M<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R
M*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT
M*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E
M9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N
M86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD
M;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A
M<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII
M9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ
M4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F
M:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I
M9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@
M)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C
M:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN
M="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H
M+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG
M+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@
M,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T
M87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN
M9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ
M6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL
M96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=
M.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD
M;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*
M;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M
M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP
M=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O
M9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@
M*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T
M('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E
M<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB
M97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M
M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[
M87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]
M("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6
M>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE
M("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U
M=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D
M>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;
M17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=
M*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R
M86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U
M-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE
M<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U
M;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@
M72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@
M6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@
M0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ
M0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E
M($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S
M*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E
M<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D
M97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@
M=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E
M($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4[
M"G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U
M:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE
M=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F
M."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R
M7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P
M("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0
M(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S
M<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY
M("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE
M.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U
M:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D
M<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!
M4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*
M;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@
M/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G
M:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B
M*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(
M12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I
M8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I
M"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H
M95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C
M86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I
M('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@
M,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER
M.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*
M;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA
M;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I
M('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P
M96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O
M;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN
M9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF
M(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@
M;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS
M=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.
M04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O
M9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?
M5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X]
M(#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P
M<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?
M4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^
M/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T
M=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB
M*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E
M86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6
M>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D
M9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI
M;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G
M;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI
M;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S
M>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[
M7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P
M(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E
M>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]
M("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN
M960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@
M)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC
M:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D
M96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%
M?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.
M5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@
M>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.
M140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE
M=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%
M04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"
M04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF
M("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]
M"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2![
M"G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*
M?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L
M(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA
M<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV
M96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*
M<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI0
M05(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O
M<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@
M9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M
M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`[
M"GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ
M.PI?7T5.1%]?"@!435!$25(``%1%35!$25(`5$5-4`````!435```````(FK
MS>\`````<&5R;'AS:2YC``````````!#04-(10```1L#.^P````<````V([_
M_V@&``!@D/__!`$``!:1__\8`0``MJ7__TP!``!8IO__L`$``+*F___<`0``
MSJ?__SP"```HJ/__8`(``/2H__^@`@``M*K__PP#``#<JO__(`,``)"K__]<
M`P``DJO__W`#```XK?__O`,``%JM___<`P``.J[__R`$``"ZL?__4`0```BR
M__]T!```4++__XP$``!*L___T`0``&"S___L!```(K3__T`%```FN?__Z`4`
M`-2Z__\@!@``>+O__YP&``#.N___O`8``,*\__\`!P``=K[__T`'````````
M$``````````#>E(``7P!`1L,`@`0````&````%2/__\B``````<!`#`````L
M````]H___Z`4````1`[`!6"!`H@$B0:2"),*`V(4"L%$R$3)1-)$TT0.`$(+
M``!@````8````&*D__^B`````$(.0$Z!`H@$EA!2D@B3"I0,9HD&E0YFR4+2
M0M-"U$+50L%$R$+60@X`0@Y`@0*(!(D&D@B3"I0,E0Z6$%#)U432T]1$D@B3
M"I0,0M)"TT+4````*````,0```"@I/__6@````!"#K`!1H@$B0:!`@)&"L%"
MR$+)0@X`0@L```!<````\````,ZD__\<`0```$(.P`%$D@B!`EB(!$;(4,%"
MTD(.`$(.P`&!`H@$D@A"B09,DPH"0I0,`EC45`K(0LE"TT(+1I0,2,C)T]1(
MB`2)!I,*E`Q$T]1"R$+)```@````4`$``(JE__]:`````$(.$$*(!$J!`FC(
M0L%>#@`````\````=`$``,"E___,`````$(.4$2(!%0.T"")!I((DPJ4#($"
ME0X"<@H.4$+!0LA"R4+20M-"U$+50@X`0@L`:````+0!``!,IO__P`$```!"
M#G!0B`2)!I((@0*3"I0,EA"7$@+4"L%"R$+)0M)"TT+40M9"UT(.`$(+<)4.
MF!29%@)>"M5"V$+91`M6U=C91)4.F!29%D;5V-E&E0Z8%)D61M5"V$+9````
M$````"`"``"@I___*``````````X````-`(``+2G__^T`````$(.4%8.T$"!
M`H@$B0:2"),*E`P"A@H.4$+!1,A"R4+20M-"U$(.`$(+```0````<`(``"RH
M__\"`````````$@```"$`@``&JC__Z8!````0@[@`5X.X"&(!(D&D@B6$($"
MDPJ4#)4.EQ*8%`)<"@[@`4+!0LA"R4+20M-"U$+50M9"UT+80@X`0@L<````
MT`(``'2I__\B`````$(.$$B(!($"4,A"P4(.`$````#P`@``=JG__^``````
M0@XP4@ZP()((@0*(!(D&`H8*#C!"P4+(0LE"TD(.`$(+5@H.,$+!0LA"R4+2
M2@X`1`L`+````#0#```2JO__@`,```!"#C!(B`2)!I((@0(#-@,*R$+!0LE"
MTE(.`$0+````(````&0#``!BK?__3@````!"#B!$B`2!`GH*P4+(0@X`0@L`
M%````(@#``",K?__2`````!"#F!"@1(`0````*`#``"\K?__^@````!"#E!:
M#M"`!)((DPJ4#($"B`2)!I4.EA`"H@H.4$+!0LA"R4+20M-"U$+50M9"#@!"
M"P`8````Y`,``'*N__\6`````$(.$$*!`D[!0@X`4``````$``!LKO__P@``
M``!"#D!&B0:2"($":(@$1LA8P4+)0M)"#@!$#D"!`H@$B0:2"$23"@)$R$+3
M0L%"R4+22@X`1`Y`@0*)!I((1(@$DPH`I````%0$``#:KO__!`4```!.#O`"
M7HD&D@B3"H$"B`0";I0,E0Z6$)<2`R`!F18"/-E2"L%"R$+50M9"UT+)0M)"
MTT340@X`0@L"8)D65I@41MA"V6#4U=;75LA"P4+)0M)"TT(.`$0.\`*!`H@$
MB0:2"),*E`R5#I80EQ*8%)D6`RP!"MA"V4(+`]P`V-E$F!29%D34U=;7V-E,
ME`R5#I80EQ*8%)D6-````/P$```VL___K@$```!"#D!"B`12D@B3"H$"B0:4
M#`-&`0K!0LA"R4+20M-"U$(.`$(+``!$````-`4``*RT__^D`````$(.,$:(
M!(D&@0("0@K!0LA"R4(.`$(+1)((;`K20@M,R$+20L%$R4(.`$0.,($"B`2)
M!D*2"``P````?`4``&B(__^(`0```$(.8$R!`HD&B`22"),*`PP!"L%"R$+)
M0M-$TD(.`$(+````'````+`%``#4M/__5@````!"#A!&@0("2L%"#@````!`
M````T`4```JU___T`````$(.4%2)!I((E`R5#H$"B`23"G:6$$:7$@)"UD+7
M4`K!0LA"R4+20M-"U$+50@X`0@L``#P````4!@``NK7__[0!````0@Y`4(@$
MB0:3"I0,EA"!`I((E0X#4`$*R$+!0LE"TD+30M1"U4+60@X`1`L````0````
M5`8``"ZW__\,````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````!
M`````````/D"`````````0`````````$`P````````$`````````#@,`````
M```=`````````+@$````````(`````````!XJP```````"$`````````"```
M```````9`````````("K````````&P`````````(`````````!H`````````
MB*L````````<``````````@`````````!`````````#8`@```````/7^_V\`
M````^`4````````%`````````&`0````````!@````````#H!@````````H`
M````````[@0````````+`````````!@`````````%0``````````````````
M``,`````````P*T````````"`````````%@%````````%``````````'````
M`````!<`````````B!@````````'`````````'@6````````"`````````!H
M!P````````D`````````&``````````>``````````@`````````^___;P``
M```!```(`````/[__V\`````&!8```````#___]O``````(`````````\/__
M;P````!.%0```````/G__V\`````"P``````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````/__________``````````#@'0```````.`=
M````````X!T```````#@'0```````.`=````````X!T```````#@'0``````
M`.`=````````X!T```````#@'0```````.`=````````X!T```````#@'0``
M`````.`=````````X!T```````#@'0```````.`=````````X!T```````#@
M'0```````.`=````````X!T```````#@'0```````.`=````````X!T`````
M``#@'0```````.`=````````X!T```````#@'0```````.`=````````X!T`
M``````#@'0```````.`=````````X!T```````#@'0```````.`=````````
MX!T```````#@'0```````.`=````````X!T```````#@'0```````.`=````
M````X!T```````#@'0```````.`=````````X!T```````#@'0```````.`=
M````````X!T```````#@'0```````.`=````````X!T```````#@'0``````
M`.`=````````X!T```````#@'0```````.`=````````X!T```````"0JP``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````"E!!4BYP;0H`````````````````````````
M````````````````````````````````````````````````````````````
M1T-#.B`H4U5312!,:6YU>"D@,30N,BXQ(#(P,C4P,C(P(%MR979I<VEO;B`Y
M9F9E8V1E,3(Q868X.#-B-C!B8F4V,&0P,#0R-3`S-F)C.#<S,#0X70!!90``
M`')I<V-V``%;````!!`%<G8V-&DR<#%?;3)P,%]A,G`Q7V8R<#)?9#)P,E]C
M,G`P7WII8W-R,G`P7WII9F5N8V5I,G`P7WIM;75L,7`P7WIA86UO,7`P7WIA
M;')S8S%P,```+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T
M92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU
M+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N
M=&5X=``N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YP<F5I;FET
M7V%R<F%Y`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`
M+F1A=&$`+F)S<P`N8V]M;65N=``N<FES8W8N871T<FEB=71E<P``````````
M````````````````````````````````````````````````````````````
M```````````````````````+`````0````(`````````<`(```````!P`@``
M`````"$````````````````````!````````````````````$P````<````"
M`````````)0"````````E`(````````@````````````````````!```````
M`````````````"$````'`````@````````"T`@```````+0"````````)```
M``````````````````0````````````````````X````!0````(`````````
MV`(```````#8`@```````"`#````````!@`````````(``````````0`````
M````-````/;__V\"`````````/@%````````^`4```````#L``````````8`
M````````"````````````````````#X````+`````@````````#H!@``````
M`.@&````````>`D````````'`````@````@`````````&`````````!&````
M`P````(`````````8!````````!@$````````.X$```````````````````!
M````````````````````3@```/___V\"`````````$X5````````3A4`````
M``#*``````````8``````````@`````````"`````````%L```#^__]O`@``
M```````8%@```````!@6````````8``````````'`````@````@`````````
M``````````!J````!`````(`````````>!8```````!X%@```````!`"````
M````!@`````````(`````````!@`````````=`````0```!"`````````(@8
M````````B!@```````!8!0````````8````5````"``````````8````````
M`'D````!````!@````````#@'0```````.`=````````L`,`````````````
M`````!``````````$`````````!^`````0````8`````````D"$```````"0
M(0```````*HO```````````````````$````````````````````A`````$`
M```"`````````$!1````````0%$```````!W00``````````````````"```
M`````````````````(P````!`````@````````"XD@```````+B2````````
M[`````````````````````0```````````````````":`````0````(`````
M````J),```````"HDP```````&@&```````````````````(````````````
M````````I````!`````#`````````'BK````````>)L````````(````````
M````````````"``````````(`````````+,````.`````P````````"`JP``
M`````(";````````"`````````````````````@`````````"`````````"_
M````#P````,`````````B*L```````"(FP````````@`````````````````
M```(``````````@`````````RP````8````#`````````)"K````````D)L`
M```````P`@````````<`````````"``````````0`````````-0````!````
M`P````````#`K0```````,"=````````0`(```````````````````@`````
M````"`````````#9`````0````,``````````+``````````H````````%``
M```````````````````(````````````````````WP````@````#````````
M`%"P````````4*`````````H````````````````````"```````````````
M`````.0````!````,````````````````````%"@````````5@``````````
M``````````$``````````0````````#M`````P``<```````````````````
M``"FH````````&8````````````````````!`````````````````````0``
M``,`````````````````````````#*$```````#_````````````````````
0`0``````````````````````
